@@ -6,7 +6,7 @@ package testing
 import (
 	gc "gopkg.in/check.v1"
 
-	"github.com/juju/loggo"
+	"github.com/juju/loggo/v2"
 )
 
 type logSuite struct{}
